==> biocViews_1.12.3.zip: biocViews/doc/createReposHtml.R <==
###################################################
### chunk number 1: 
###################################################
library("biocViews")


###################################################
### chunk number 2: params
###################################################
reposRoot <- "path/to/reposRoot"
## The names are essential
contribPaths <- c(source="src/contrib", win.binary="bin/windows/contrib/2.4",
                  mac.binary.universal="bin/macosx/universal/contrib/2.4",
                  mac.binary.leopard="bin/macosx/leopard/contrib/2.4")


###################################################
### chunk number 3: extractVigs eval=FALSE
###################################################
## extractVignettes(reposRoot, contribPaths["source"])


###################################################
### chunk number 4: controlFiles eval=FALSE
###################################################
## genReposControlFiles(reposRoot, contribPaths)


###################################################
### chunk number 5: exampleOfHtmlDesign eval=FALSE
###################################################
## ## Define classes like this for each logical document chunk
## setClass("pdAuthorMaintainerInfo", contains="PackageDetail")
## setClass("pdVignetteInfo", contains="PackageDetail")
## 
## ## Then define a htmlValue method
## setMethod("htmlValue", signature(object="pdDescriptionInfo"),
##           function(object) {
##               node <- xmlNode("p", cleanText(object@Description),
##                               attrs=c(class="description"))
##               node
##           })
## 
## ## Then you can make use of all this...
## ## Assume object contains a PackageDetail instance
## authorInfo <- as(object, "pdAuthorMaintainerInfo")
## dom$addNode(htmlValue(authorInfo))
##

==> biocViews_1.16.2.zip: biocViews/doc/createReposHtml.R <==
###################################################
### chunk number 1: 
###################################################
library("biocViews")


###################################################
### chunk number 2: params
###################################################
reposRoot <- "path/to/reposRoot"
## The names are essential
contribPaths <- c(source="src/contrib",
                  win.binary="bin/windows/contrib/2.6",
                  win64.binary="bin/windows64/contrib/2.6",
                  mac.binary.leopard="bin/macosx/leopard/contrib/2.6")


###################################################
### chunk number 3: extractVigs eval=FALSE
###################################################
## extractVignettes(reposRoot, contribPaths["source"])


###################################################
### chunk number 4: controlFiles eval=FALSE
###################################################
## genReposControlFiles(reposRoot, contribPaths)


###################################################
### chunk number 5: exampleOfHtmlDesign eval=FALSE
###################################################
## ## Define classes like this for each logical document chunk
## setClass("pdAuthorMaintainerInfo", contains="PackageDetail")
## setClass("pdVignetteInfo", contains="PackageDetail")
## 
## ## Then define a htmlValue method
## setMethod("htmlValue", signature(object="pdDescriptionInfo"),
##           function(object) {
##               node <- xmlNode("p", cleanText(object@Description),
##                               attrs=c(class="description"))
##               node
##           })
## 
## ## Then you can make use of all this...
## ## Assume object contains a PackageDetail instance
## authorInfo <- as(object, "pdAuthorMaintainerInfo")
## dom$addNode(htmlValue(authorInfo))
##
